Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4295)

Unified Diff: chrome/installer/setup/install_worker.cc

Issue 2507293005: Force migrate all clients from multi-install back to single-install. (Closed)
Patch Set: gab comments Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/installer/mini_installer/regkey.cc ('k') | chrome/installer/setup/installer_state.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/setup/install_worker.cc
diff --git a/chrome/installer/setup/install_worker.cc b/chrome/installer/setup/install_worker.cc
index 9b36e816d781fa80650d7ac651a94e9c0188e31b..b1808113f81969fcf32c3cd51fc04c4d1715e64f 100644
--- a/chrome/installer/setup/install_worker.cc
+++ b/chrome/installer/setup/install_worker.cc
@@ -897,12 +897,9 @@ void AddMigrateUsageStatesWorkItems(const InstallationState& original_state,
return;
}
- const ProductState* chrome_state = original_state.GetProductState(
- installer_state.system_install(),
- BrowserDistribution::CHROME_BROWSER);
- // Bail out if there is not an existing multi-install Chrome that is being
- // updated.
- if (!chrome_state || !chrome_state->is_multi_install()) {
+ // Bail out if an existing multi-install Chrome is not being migrated to
+ // single-install.
+ if (!installer_state.is_migrating_to_single()) {
VLOG(1) << "No multi-install Chrome found to migrate to single-install.";
return;
}
« no previous file with comments | « chrome/installer/mini_installer/regkey.cc ('k') | chrome/installer/setup/installer_state.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698